@@ -19,13 +19,15 @@ xandikos_cleanup() {
 
 run_xandikos()
 {
-	${XANDIKOS} -p5233 -llocalhost -d ${SERVEDIR} "$@" 2>&1 >$DAEMON_LOG &
+	PORT="$1"
+	shift 1
+	${XANDIKOS} -p${PORT} -llocalhost -d ${SERVEDIR} "$@" 2>&1 >$DAEMON_LOG &
 	XANDIKOS_PID=$!
 	trap xandikos_cleanup 0 EXIT
 	i=0
 	while [ $i -lt 10 ]
 	do
-		if curl http://localhost:5233/ >/dev/null; then
+		if curl http://localhost:${PORT}/ >/dev/null; then
 			break
 		fi
 		sleep 1
