@@ -32,6 +32,7 @@ import logging
 import os
 import posixpath
 import shutil
+import urllib.parse
 
 from xandikos import __version__ as xandikos_version
 from xandikos import (access, apache, caldav, carddav, quota, sync, webdav,
@@ -78,7 +79,9 @@ def render_jinja_page(name, accepted_content_languages, **kwargs):
     # TODO(jelmer): Support rendering other languages
     encoding = 'utf-8'
     template = jinja_env.get_template(name)
-    body = template.render(version=xandikos_version, **kwargs).encode(encoding)
+    body = template.render(
+        version=xandikos_version,
+        urljoin=urllib.parse.urljoin, **kwargs).encode(encoding)
     return ([body], len(body), None, 'text/html; encoding=%s' % encoding,
             ['en-UK'])
 
@@ -130,11 +133,11 @@ class ObjectResource(webdav.Resource):
             (name, etag) = self.store.import_one(
                 self.name, self.content_type, data,
                 replace_etag=extract_strong_etag(replace_etag))
-        except InvalidFileContents:
+        except InvalidFileContents as e:
             # TODO(jelmer): Not every invalid file is a calendar file..
             raise webdav.PreconditionFailure(
                 '{%s}valid-calendar-data' % caldav.NAMESPACE,
-                'Not a valid calendar file.')
+                'Not a valid calendar file: %s' % e.error)
         except DuplicateUidError:
             raise webdav.PreconditionFailure(
                 '{%s}no-uid-conflict' % caldav.NAMESPACE,
@@ -277,11 +280,11 @@ class StoreBasedCollection(object):
     def create_member(self, name, contents, content_type):
         try:
             (name, etag) = self.store.import_one(name, content_type, contents)
-        except InvalidFileContents:
+        except InvalidFileContents as e:
             # TODO(jelmer): Not every invalid file is a calendar file..
             raise webdav.PreconditionFailure(
                 '{%s}valid-calendar-data' % caldav.NAMESPACE,
-                'Not a valid calendar file.')
+                'Not a valid calendar file: %s' % e.error)
         except DuplicateUidError:
             raise webdav.PreconditionFailure(
                 '{%s}no-uid-conflict' % caldav.NAMESPACE,
@@ -344,12 +347,14 @@ class StoreBasedCollection(object):
     def get_body(self):
         raise NotImplementedError(self.get_body)
 
-    def render(self, accepted_content_types, accepted_content_languages):
+    def render(self, self_url, accepted_content_types,
+               accepted_content_languages):
         content_types = webdav.pick_content_types(
             accepted_content_types, ['text/html'])
         assert content_types == ['text/html']
         return render_jinja_page(
-            'collection.html', accepted_content_languages, collection=self)
+            'collection.html', accepted_content_languages, collection=self,
+            self_url=self_url)
 
     def get_is_executable(self):
         return False
@@ -559,11 +564,13 @@ class CollectionSetResource(webdav.Collection):
         # RFC2518, section 8.6.2 says this should recursively delete.
         shutil.rmtree(p)
 
-    def render(self, accepted_content_types, accepted_content_languages):
+    def render(self, self_url, accepted_content_types,
+               accepted_content_languages):
         content_types = webdav.pick_content_types(
             accepted_content_types, ['text/html'])
         assert content_types == ['text/html']
-        return render_jinja_page('root.html', accepted_content_languages)
+        return render_jinja_page(
+            'root.html', accepted_content_languages, self_url=self_url)
 
     def get_is_executable(self):
         return False
@@ -585,11 +592,15 @@ class RootPage(webdav.Resource):
     def __init__(self, backend):
         self.backend = backend
 
-    def render(self, accepted_content_types, accepted_content_languages):
+    def render(self, self_url, accepted_content_types,
+               accepted_content_languages):
         content_types = webdav.pick_content_types(
             accepted_content_types, ['text/html'])
         assert content_types == ['text/html']
-        return render_jinja_page('root.html', accepted_content_languages)
+        return render_jinja_page(
+            'root.html', accepted_content_languages,
+            principals=self.backend.find_principals(),
+            self_url=self_url)
 
     def get_body(self):
         raise KeyError
@@ -718,6 +729,15 @@ class PrincipalBare(CollectionSetResource, Principal):
                 pass
         return p
 
+    def render(self, self_url, accepted_content_types,
+               accepted_content_languages):
+        content_types = webdav.pick_content_types(
+            accepted_content_types, ['text/html'])
+        assert content_types == ['text/html']
+        return render_jinja_page(
+            'principal.html', accepted_content_languages, principal=self,
+            self_url=self_url)
+
 
 class PrincipalCollection(Collection, Principal):
     """Principal user resource."""
@@ -770,6 +790,10 @@ class XandikosBackend(webdav.Backend):
         if create_defaults:
             create_principal_defaults(self, principal)
 
+    def find_principals(self):
+        """List all of the principals on this server."""
+        return self._user_principals
+
     def get_resource(self, relpath):
         relpath = posixpath.normpath(relpath)
         if relpath == '/':
@@ -813,10 +837,16 @@ class XandikosApp(webdav.WebDAVApp):
 
     def __init__(self, backend, current_user_principal):
         super(XandikosApp, self).__init__(backend)
+
+        def get_current_user_principal(env):
+            try:
+                return current_user_principal % env
+            except KeyError:
+                return None
         self.register_properties([
             webdav.ResourceTypeProperty(),
             webdav.CurrentUserPrincipalProperty(
-                current_user_principal),
+                get_current_user_principal),
             webdav.PrincipalURLProperty(),
             webdav.DisplayNameProperty(),
             webdav.GetETagProperty(),
